==> core-0.3.0.tgz: package/lib/net/ConnectionPool.js <==
var Event = require('../event/Event.js').Event;
var ErrorEvent = require('../event/ErrorEvent.js').ErrorEvent;
var EventDispatcher = require('../event/EventDispatcher.js').EventDispatcher; 
var Class = require('../class/Class.js').Class;
var net = require('net');

var Socket = require('./Socket.js').Socket;

var ConnectionPool = function(){

    this.Extends = EventDispatcher;

    this._sockets = [];
    this._callbacks = [];
    this._options = null;
    
    this.initialize = function(options){
        this._options = options;
		this._connect(); 
    };
        
	this._connect = function(){
        for(var i=0;i<this._options.connections;i++){
			var socket = new Socket(this._options.port, this._options.host);
            console.log('    - ConnectionPool: Created socket [' + i + ']');
            this._refineSocketHandlers(socket);
            this._sockets.push(socket);
        }
    };

    this.givebackSocket = function(socket){
		var self = this;

		if(socket.bufferSize() == 0){
			this._givebackSocket(socket);
		}else{
			socket.on('drain', function(){
				self._givebackSocket(socket);
			});
		}
    };

	this._givebackSocket = function(socket){
		this._refineSocketHandlers(socket);
        this._sockets.push(socket);

        if(this._sockets.length>0 &&  this._callbacks.length > 0){
            socket = this._sockets.shift();
            var cb = this._callbacks.shift();
            cb(socket);
        }
	}

    this.getSocket = function(cb){
        if(this._sockets.length>0 && this._callbacks.length == 0){
            var socket = this._sockets.shift();
            cb(socket);
        } else {
            console.log('    - ConnectionPool: there is no socket avalible. Please increase "connections" variable!');
            this._callbacks.push(cb);
        }
    }
    
    this._refineSocketHandlers = function(socket){
		socket._refineHandlers();
    };
};

ConnectionPool = new Class(new ConnectionPool());
exports.ConnectionPool = ConnectionPool;

==> core-0.4.6.tgz: package/lib/net/ConnectionPool.js <==
var Event = require('../event/Event.js').Event;
var ErrorEvent = require('../event/ErrorEvent.js').ErrorEvent;
var EventDispatcher = require('../event/EventDispatcher.js').EventDispatcher; 
var Class = require('../class/Class.js').Class;
var net = require('net');

var Socket = require('./Socket.js').Socket;

var ConnectionPool = function(){

    this.Extends = EventDispatcher;

    this._sockets = [];
    this._callbacks = [];
    this._options = null;
    
    this.initialize = function(options){
        this._options = options;
		this._connect(); 
    };
        
	this._connect = function(){
        for(var i=0;i<this._options.connections;i++){
			var socket = new Socket(this._options.port, this._options.host);
            console.log('    - ConnectionPool: Created socket [' + i + ']. Connecting...');
            this._refineSocketHandlers(socket);
            this._sockets.push(socket);
        }
    };

    this.givebackSocket = function(socket){
		var self = this;

		if(socket.bufferSize() == 0){
			this._givebackSocket(socket);
		}else{
			socket.on('drain', function(){
				self._givebackSocket(socket);
			});
		}
    };

	this._givebackSocket = function(socket){
		this._refineSocketHandlers(socket);
        this._sockets.push(socket);

        if(this._sockets.length>0 &&  this._callbacks.length > 0){
            socket = this._sockets.shift();
            var cb = this._callbacks.shift();
            cb(socket);
        }
	}

    this.getSocket = function(cb){
        if(this._sockets.length>0 && this._callbacks.length == 0){
            var socket = this._sockets.shift();
            cb(socket);
        } else {
            console.log('    - ConnectionPool: there is no socket avalible. Please increase "connections" variable!');
            this._callbacks.push(cb);
        }
    }
    
    this._refineSocketHandlers = function(socket){
		socket._refineHandlers();
    };
};

ConnectionPool = new Class(new ConnectionPool());
exports.ConnectionPool = ConnectionPool;
